@@ -1,5 +1,3 @@
-library(tinytest)
-
 expect_error(esp_get_hydrobasin(epsg = 3367))
 expect_error(esp_get_hydrobasin(domain = "f"))
 
@@ -12,8 +10,10 @@ if (giscoR::gisco_check_access()) {
     epsg = 3857
   ))
 
-  l <- esp_get_hydrobasin(resolution = "10",
-                          epsg = 3857)
+  l <- esp_get_hydrobasin(
+    resolution = "10",
+    epsg = 3857
+  )
 
   expect_true(sf::st_crs(l) == sf::st_crs(3857))
   expect_silent(esp_get_hydrobasin(resolution = "10"))
@@ -22,5 +22,4 @@ if (giscoR::gisco_check_access()) {
   expect_silent(esp_get_hydrobasin(resolution = "3"))
   expect_silent(esp_get_hydrobasin(resolution = "6.5", domain = "landsea"))
   expect_silent(esp_get_hydrobasin(resolution = "3", domain = "landsea"))
-
 }
